@@ -24,18 +24,16 @@ def datetime_string():
 
 def file_exists(filepath):
     """
-    check to see if the file specified in filepath exists
-    
+    Check to see if the file specified in filepath exists
+    A pure wrapper for os.path.isfile()
+
     Inputs:
         filepath: string
-        
+
     Output:
-        file_exists: bool
+        bool (True if file exists, False if it does not)
     """
-    file_exists = False
-    if os.path.isfile(filepath):
-        file_exists = True
-    return file_exists
+    return os.path.isfile(filepath)
 
 
 def get_bins(min_edge, max_edge, bin_width=1):
@@ -60,7 +58,8 @@ def get_bins(min_edge, max_edge, bin_width=1):
         print("get_bins: Warning bin_width may not exactly divide up the given range of values.")
 
     bin_edges = np.arange(min_edge, max_edge + bin_width, bin_width)
-    bin_centers = np.arange(min_edge + bin_width / 2, max_edge + bin_width / 2, bin_width)
+    bin_centers = np.arange(min_edge + bin_width / 2,
+                            max_edge + bin_width / 2, bin_width)
     return bin_edges, bin_centers
 
 
@@ -84,7 +83,8 @@ def get_offdiag_vals(array):
     Adapted from:
         https://stackoverflow.com/a/44395030/1886357
     """
-    assert is_symmetric(array), print("get_offdiag_vals() requires symmetric array")
+    assert is_symmetric(array), print(
+        "get_offdiag_vals() requires symmetric array")
     num_rows = array.shape[0]
     # get indices of lower diag, not inclucing diagonal
     offdiag_indices = np.tril_indices(num_rows, k=-1)
